
#
# Note Regarding Bundled Libraries:
#
# The Cement package (upstream) includes a backport of pkgutil.py
# from the standard library.  This backported library is only conditionally
# used where 'get_data' can not be imported from 'pkgutil' (Python < 2.6).
# For Example:
#
#   try:
#       from pkgutil import get_data
#   except ImportError:
#       from cement.backports.pkgutil import get_data 
#
#
# Per the Fedora Packaging Guidelines, it is acceptable to leave this bundled
# software as is.  Please see:
#
#   https://fedoraproject.org/wiki/Packaging:Treatment_Of_Bundled_Libraries
#
#
# Specifically the section on 'Conditionalized Functionality'.
#

%{!?pyver: %global pyver %(%{__python} -c "import sys ; print sys.version[:3]")}

%if ! (0%{?fedora} > 12 || 0%{?rhel} > 5)
%{!?python_sitelib: %global python_sitelib %(%{__python} -c "from distutils.sysconfig import get_python_lib; print(get_python_lib())")}
%endif

%global _with_doc 1
%global _with_tests 1

Name: python-cement
Version: 0.8.18
Release: 2%{?dist}
Summary: CLI Application Framework for Python
Group: Development/Libraries    

# Everything is MIT except for %%{python_sitelib}/cement/backports/pkgutil.py 
# which is Python 
License: MIT and Python

URL: http://builtoncement.org
Source0: http://builtoncement.org/cement/0.8/source/cement-%{version}.tar.gz 

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)
BuildArch: noarch

BuildRequires: python2-devel, python-setuptools
BuildRequires: python-configobj, python-jsonpickle, python-genshi
Requires: python, python-configobj, python-jsonpickle, python-genshi
Requires: python-setuptools

%if 0%{?el5}
BuildRequires: python-simplejson
Requires: python-simplejson
%endif

%if 0%{?_with_tests}
BuildRequires: python-nose, python-coverage
%endif

#Patch0: cement-0.8.18-testing.patch
Patch1: cement-0.8.18-setuptools.patch
Patch2: cement-0.8.18-paths.patch

%description
Cement is an advanced CLI Application Framework for Python. It promotes code
re-use by way of a plugin system that enables plugins to be shared between any
application built on Cement.  The MVC and overall framework design is very
much inspired by the TurboGears2 web framework.  Its goal is to introduce a
standard, and feature-full platform for both simple and complex command line
applications as well as support rapid development needs without sacrificing
quality.

At a minimum, Cement configures the following features for every application:

    * Multiple Configuration file parsing (default: /etc, ~/)
    * Command line argument and option parsing
    * Dual Console/File Logging Support
    * Internal and External (3rd Party) Plugin support
    * Basic "hook" support
    * Model/View/Controller support for advanced application design
    * Text output rendering with Genshi templates
    * Json output rendering allows other programs to access your CLI-API

%package devtools 
Summary: Development Tools for the Cement CLI Application Framework
Group: Development/Languages
Requires: python-tempita, python-paste-script
Requires: %{name} = %{version}-%{release}

%description devtools 
The Cement devtools package provides tools and libraries needed for developing 
applications on top of the Cement CLI Application Framework.

%if 0%{?_with_doc}
%package doc
Summary: Documentation for Cement
Group: Documentation
BuildRequires: python-configobj, python-genshi, python-jinja2, python-sphinx
BuildRequires: python-jsonpickle

%description doc
This package provides the Sphinx documentation for the Cement CLI Application
Framework for Python.
%endif

%prep
%setup -q -n cement-%{version}
#%%patch0 -p1 -b .testing
%patch1 -p1 -b .setuptools
%patch2 -p1 -b .paths

mv src/cement/LICENSE.psf .

%build
pushd src/cement/
%{__python} setup.py build
popd

pushd src/cement.devtools/
%{__python} setup.py build
popd

%if 0%{?_with_tests}
pushd src/cement.test/
%{__python} setup.py build
popd
%endif

%if 0%{?_with_doc}
# newer versions of sphinx create these directories
#mkdir -p doc/build/html doc/source/_static/
sphinx-build doc/source doc/build/html

# cleanup 
rm -rf  build/lib/tests \
        doc/build/html/.doctrees \
        doc/build/html/.buildinfo
%endif


%install
rm -rf %{buildroot}

pushd src/cement/
%{__python} setup.py install -O1 \
    --skip-build \
    --root %{buildroot}
popd

pushd src/cement.devtools/
%{__python} setup.py install -O1 \
    --skip-build \
    --root %{buildroot}
popd

%check
%if 0%{?_with_tests}
pushd src/cement.test
%{__python} setup.py nosetests 
popd
%endif

%clean
rm -rf %{buildroot}


%files
%defattr(-,root,root,-)
%doc README LICENSE LICENSE.psf ChangeLog
%dir %{python_sitelib}/cement
%{python_sitelib}/cement/__init__.py*
%{python_sitelib}/cement/core/
%{python_sitelib}/cement/backports/
%{python_sitelib}/cement-%{version}-py%{pyver}.egg-info/

%files devtools 
%defattr(-,root,root,-)
%doc src/cement.devtools/README src/cement.devtools/LICENSE
%{python_sitelib}/cementdevtools/
%{python_sitelib}/cement.devtools-%{version}-py%{pyver}.egg-info/

%if 0%{?_with_doc}
%files doc
%defattr(-,root,root,-)
%doc doc/build/html
%endif

%changelog
* Tue Jul 12 2011 BJ Dierkes <wdierkes@rackspace.com> - 0.8.18-2
- Removed Patch0: cement-testing.patch (reworked in Patch2)
- Added Patch1: cement-0.8.18-setuptools.patch
- Added Patch2: cement-0.8.18-paths.patch
- No longer include 'test_runner.py' hack (just use setup.py nosetests)

* Thu Jul 07 2011 BJ Dierkes <wdierkes@rackspace.com> - 0.8.18-1
- Latest sources from upstream.  Full changelog available at:
  http://builtoncement.org/cement/0.8/doc/changes.html
- BuildRequire: python-coverage for tests

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.8.16-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Feb 07 2011 BJ Dierkes <wdierkes@rackspace.com> - 0.8.16-1
- Latest sources from upstream.  Full changelog available at:
  http://builtoncement.org/cement/0.8/ChangeLog

* Tue Jan 11 2011 BJ Dierkes <wdierkes@rackspace.com> - 0.8.14-6
- Requires: python-setuptools (for pkg_resources)

* Mon Jan 03 2011 BJ Dierkes <wdierkes@rackspace.com> - 0.8.14-5
- Added comment at top of spec regarding bundled 'pkgutil'

* Thu Dec 16 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.14-4
- Change comment for License to reference install location rather
  than source location of pkgutil.

* Tue Dec 14 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.14-3
- No longer use a %%{python} macro for the python package name
- BuildRequires: python2-devel per FPG

* Tue Dec 14 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.14-2
- Cleaned up use of macros a bit (no longer use %%{real_name}
- Include %%{python_sitelib}/cement dir under base package
- No longer pass '--single-version-externally-managed'

* Thu Dec 09 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.14-1
- Latest sources from upstream
- Add in -devtools package (now bundled in upstream source)
- Optionally run nose tests under cement.test

* Mon Dec 06 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.12-1
- Latest sources from upstream.
- Changed licse to MIT and Python (pkgutil backport)

* Wed Dec 01 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.10-1
- Latest sources from upstream
- Removed -devtools package, will create separate package for it

* Fri Jun 11 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.6-1
- Latest source from upstream
- Remove -devel package (moved to -devtools following upstream)
- Updated Patch0: cement-0.8.6-noreqs.patch
- Adding Patch1: cement-0.8.6-doc.patch (again)

* Mon Jun 07 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8.4-1
- Latest sources from upstream
- Re-write Patch0: noreqs.patch
- Removed Patch1: cement-0.8-doc.patch (no longer applicable)
- Removed Patch2: cement-0.8-tests.patch (applied upstream)

* Fri Apr 30 2010 BJ Dierkes <wdierkes@rackspace.com> - 0.8-1
- Initial spec build
